@@ -10,7 +10,7 @@ import ctypes
 import sys
 import os
 
-__SONAMES = (18, 17, 13, 10, 5, 4)
+__SONAMES = (23, 18, 17, 13, 10, 5, 4)
 
 
 def _get_nacl():
